@@ -92,7 +92,7 @@ def cal_performance(save_path, start_date, end_date):
 
     start_date_year = datetime.datetime.strptime(start_date, '%Y-%m-%d').year
     end_date_year = datetime.datetime.strptime(end_date, '%Y-%m-%d').year
-    year_list = list(range(start_date_year, end_date_year))
+    year_list = list(range(start_date_year, end_date_year + 1))
     for y in year_list: result_dict[str(y)] = []
 
     if os.path.isfile(save_path):
