@@ -28,7 +28,7 @@ class Plot:
     init = True
 
 
-    def __new__(self, filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, settings):
+    def __new__(self, filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, settings, width):
 
         chart_bg = self.chart_bg
 
@@ -37,7 +37,7 @@ class Plot:
         empty_line_chart = components.empty_line_chart()
         checkbox_div = components.update_checkbox_div(para_dict, result_df)
         col_df = result_df.columns.values.tolist()
-        df_col = pd.DataFrame([['---' for column in col_df]], columns=col_df)
+        df_col = pd.DataFrame([['-----' for column in col_df]], columns=col_df)
         performance_matrix = components.update_performance_matrix(start_date, end_date, df_col.iloc[0].copy(), para_dict)
         filter_div = components.update_filter_div([])
 
@@ -120,7 +120,7 @@ class Plot:
                 ])
             ),
 
-        ], style={'width':'950px','margin':'auto','padding':'0px','color':'white'})
+        ], style={'width':str(width)+'px','margin':'auto','padding':'0px','color':'white'})
 
 
 
@@ -239,22 +239,36 @@ class Plot:
                             line_colour = self.graph_df.iloc[self.line_selected].line_colour
                             df = pd.read_csv(save_path)
                             df_chart = components.prepare_df_chart(df)
-                            fig_line = components.generate_chart_2(df_chart, line_colour)
+                            # fig_line = components.generate_chart_2(df_chart, line_colour)
 
                             self.chart_type = 2
                             chart1_button_text = '< Back'
 
-                            sub_chart1_area = {}
-                            sub_chart2_area = {}
-                            sub_chart1 = components.generate_subchart(df_chart, settings['subchart_1'][0],
-                                                                      settings['subchart_1'][1], 'yellow')
-                            sub_chart2 = components.generate_subchart(df_chart, settings['subchart_2'][0],
-                                                                      settings['subchart_2'][1], '#FF01FE')
+                            # Generate subscharts first
+                            subchart_count = 0
+                            try:
+                                sub_chart1 = components.generate_subchart(df_chart, settings['subchart_1'][0],
+                                                                          settings['subchart_1'][1], 'yellow')
+                                sub_chart1_area = {}
+                                subchart_count += 1
+                            except:
+                                pass
+                            try:
+                                sub_chart2 = components.generate_subchart(df_chart, settings['subchart_2'][0],
+                                                                          settings['subchart_2'][1], '#FF01FE')
+                                sub_chart2_area = {}
+                                subchart_count += 1
+                            except:
+                                pass
+
+                            # Generate Chart 2 after knowing subchart count
+                            fig_line = components.generate_chart_2(df_chart, line_colour, 340 - subchart_count*60)
+
 
 
                             # Histograms
                             period = settings['histogram_period']
-                            # first column of the 5 charts
+                            # First column of the 5 charts
                             title_list = [dbc.Col(width=1)]
                             pct_list = [dbc.Col(html.Div('pct_change', style={'font-size': '12px', 'margin-top': '60px',
                                                                               'margin-left': '40px',
